# Contributing

First of all, thank you for choosing to contribute to Syntrend!
This project will not have a chance to grow and provide the impact it intends to have without your contributions, ideas, and use cases.

## Ways to Contribute

All means of contributing to this project is welcome. Maintenance of Syntrend focuses on the greatest achievable
levels of quality, documentation, and regression testing to ensure the trust and respect of our users as they intend
to use this tool for Quality Assurance and Development processes.

Read the following sections for general information on how to contribute to help us achieve this objective.

### First Time Contributors

For any developer looking to make contributions to the project, it's helpful to find an Issue tagged with "good first issue".
These issues have been identified as generally easy items that would allow someone the opportunity to set up the
development environment and to get familiar with the application's logic.

### Submit Bug Reports

### Submit or add to Feature Requests

### Pull Requests

## Documentation

The project uses reStructuredText for it's documentation format. It provides substantial flexibility to add features
above what Markdown supports while automating tasks using Sphinx. Other formats would be more optimal
